HBN

HBN(self, q_overtopping, model_uncertainty=True)

Calculate the HBN for a location

Methods

Name Description
calculate Execute a calculation
calculate_location Calculate the exceedance probability of the variable at a given set of levels.
set_overtopping_discharge Change the average overtopping discharge
set_range Set the lower and upper bound of the fragility curve.
set_step_size Change the step size of the frequency line.
set_verbose Show info during calculation.
use_model_uncertainty Use model uncertainty when calculating a frequency line.

calculate

HBN.calculate(input)

Execute a calculation

Parameters

Name Type Description Default
input Union[Location, HRDatabase] The input required

calculate_location

HBN.calculate_location(location)

Calculate the exceedance probability of the variable at a given set of levels.

Parameter

location : Location The Location object

Returns

Name Type Description
FrequencyLine Frequency line of the crest level

set_overtopping_discharge

HBN.set_overtopping_discharge(q_overtopping)

Change the average overtopping discharge

Parameters

Name Type Description Default
q_overtopping float The average overtopping discharge [m3/m/s] required

set_range

HBN.set_range(lower_bound=None, upper_bound=None)

Set the lower and upper bound of the fragility curve.

Parameters

Name Type Description Default
levels list The levels at which the exceedance probability has to be calculated required

set_step_size

HBN.set_step_size(step_size)

Change the step size of the frequency line.

Parameters

Name Type Description Default
step_size float The step size of the frequency line required

set_verbose

HBN.set_verbose(verbose)

Show info during calculation.

Parameters

Name Type Description Default
verbose bool Show info during calculation. required

use_model_uncertainty

HBN.use_model_uncertainty(model_uncertainty)

Use model uncertainty when calculating a frequency line.

Parameters

Name Type Description Default
model_uncertainty bool Enable or disable the use of model uncertainties required